Group {
  DefineGroup[Domain_Disp, Domain_Force, Domain_Force_Sur, Domain_Force_Lin] ;
  DomainTot = Region[ {Domain_Disp,Domain_Force} ];
}

Jacobian {
  { Name Vol ;
    Case { 
      { Region All ; Jacobian Vol ; }
    }
  }
  { Name Sur ;
    Case { { Region All ; Jacobian Sur ; }
    }
  }
  { Name Lin ;
    Case { { Region All ; Jacobian Lin ; }
    }
  }
  { Name SurLinVol ;
    Case {
      { Region Domain_Force_Sur ; Jacobian Sur ; }
      { Region Domain_Force_Lin ; Jacobian Lin ; }
      { Region All ; Jacobian Vol ; }
    }
  }
}

Integration {
  { Name GradGrad ;
    Case { 
      { Type Gauss ;
	Case { 
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  2 ; } 
	  { GeoElement Triangle    ; NumberOfPoints  4 ; } 
	  { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  34 ; }
	  { GeoElement Prism       ; NumberOfPoints  9 ; } }
      }
    }
  }
}

/* -------------------------------------------------------------------------*/

/* Mechanics - Displacement ux, uy, uz formulations */

FunctionSpace {
  { Name H_u_Mec3D ; Type Vector ;
    BasisFunction {
      { Name sxn ; NameOfCoef uxn ; Function BF_NodeX ;
	dFunction {BF_NodeX_D1, BF_NodeX_D2 } ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
      { Name syn ; NameOfCoef uyn ; Function BF_NodeY ;
	dFunction {BF_NodeY_D1,BF_NodeY_D2 } ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
      { Name szn ; NameOfCoef uzn ; Function BF_NodeZ ;
	dFunction {BF_NodeZ_D1,BF_NodeZ_D2 } ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef uxn ;
        EntityType NodesOf ; NameOfConstraint DeplacementX ; }
      { NameOfCoef uyn ;
        EntityType NodesOf ; NameOfConstraint DeplacementY ; }
      { NameOfCoef uzn ;
        EntityType NodesOf ; NameOfConstraint DeplacementZ ; }
    }
  }
}

/*------------------------------------------------------------------------*/

Formulation {
  { Name Mec3D_u ; Type FemEquation ;
    Quantity {
      { Name u ; Type Local ; NameOfSpace H_u_Mec3D ; }
    }
    Equation {
      Galerkin { [ C_m_11[] * Dof{D1 u} , {D1 u} ] ;
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; } 
      Galerkin { [ C_m_22[] * Dof{D2 u} , {D2 u} ] ;
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; } 
      Galerkin { [ C_m_12[] * Dof{D2 u} , {D1 u} ] ;
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; } 
      Galerkin { [ C_m_21[] * Dof{D1 u} , {D2 u} ] ;
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; } 
      Galerkin { DtDt [ rho[] * Dof{u} , {u} ];
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; }
      Galerkin { [ -K[] , {u} ] ;
	In Domain_Disp ; Jacobian Vol ; Integration GradGrad ; }
      Galerkin { [ -F[] , {u} ] ;
	In Domain_Force; Jacobian SurLinVol; Integration GradGrad; }
    }
  }
}

/*------------------------------------------------------------------------*/

Resolution {
  { Name Mec3D_u ;
    System {
      { Name Sys_Mec; NameOfFormulation Mec3D_u; }
    }
    Operation {
      Generate[Sys_Mec]; Solve[Sys_Mec]; SaveSolution[Sys_Mec] ;
    }
  }
}

/*------------------------------------------------------------------------*/

PostProcessing {
  { Name Mec3D_u ; NameOfFormulation Mec3D_u ;  
    PostQuantity {
      { Name u ; Value { Term { [ {u} ] ; In Domain_Disp  ; } } }
      { Name ux ; Value { Term { [CompX[{u}]] ; In Domain_Disp  ; } } }
      { Name uy ; Value { Term { [CompY[{u}]] ; In Domain_Disp  ; } } }
      { Name uz ; Value { Term { [CompZ[{u}]] ; In Domain_Disp  ; } } }
      { Name epsI ; Value { Term { [ {D1 u} ] ; In Domain_Disp ; } } }
      { Name epsII ; Value { Term { [ {D2 u} ] ; In Domain_Disp ; } } }

      { Name epsx ; Value { Term { [Vector[CompX[{D1 u}],0,0 ] ]   ; In Domain_Disp ; } } }
      { Name epsy ; Value { Term { [Vector[0, CompY[{D1 u}],0 ] ]  ; In Domain_Disp ; } } }
      { Name epsz ; Value { Term { [Vector[0, 0, CompZ[{D1 u}] ] ] ; In Domain_Disp ; } } }

      { Name epsxy ; Value { Term { [Vector[CompX[{D2 u}],0,0 ] ]   ; In Domain_Disp ; } } }
      { Name epsyz ; Value { Term { [Vector[0, CompY[{D2 u}],0 ] ]  ; In Domain_Disp ; } } }
      { Name epszx ; Value { Term { [Vector[0, 0, CompZ[{D2 u}] ] ] ; In Domain_Disp ; } } }   

      { Name um ; Value { Term { [Norm[{u}]] ; In Domain_Disp  ; } } }
    } 
  }
}
