Group {
  Top = Region[ {102} ];
  Bottom = Region [ {101} ];
  Edge1 = Region [{103}];
  Beam = Region[ {100} ];

  Domain_Force_Sur = Region[ Top ];
  // Domain_Force_Lin = Region[ Edge1 ];
  Domain_Disp = Region[ Beam ];
  Domain_Force = Region[ Domain_Force_Sur ];
}

/* -----------------------------------------------------------------------*/

Function {
  DefineConstant[
    young = {2.06e11, Name "Input/Materials/0Young modulus [Pa]",
      Visible 1},
    poisson = {0.3, Name "Input/Materials/1Poisson coeficient",
      Visible 1},
    rh = {7700, Name "Input/Materials/2Mass density", Label "Mass density [kg/m^3]",
      Visible 1}
  ];

  E = young; // Young of steal.
  sig = poisson; // Poisson
  
  lame_lambda = sig*E / (1-2*sig) / (1+sig); 
  lame_mu = E / 2 / (1+sig);

  Printf("lambda = %g", lame_lambda);
  Printf("mu     = %g", lame_mu);

  c1 = lame_lambda + 2*lame_mu;
  c3 = lame_lambda;
  c2 = lame_mu; // factor 2 is combined into D2.

  C_m_11[ Beam ] = Tensor[ c1, c3, c3, 
                           c3, c1, c3,
                           c3, c3, c1 ];
  C_m_12[ Beam ] = Tensor[ 0, 0, 0, 
                           0, 0, 0,
                           0, 0, 0 ];
  C_m_21[ Beam ] = Tensor[ 0, 0, 0, 
                           0, 0, 0,
                           0, 0, 0 ];
  C_m_22[ Beam ] = Tensor[ c2, 0, 0,
                           0, c2, 0,
                           0, 0, c2 ];

  rho[]= rh;
  F[Domain_Force] = Vector[1/1e-3/1e-3,0,0];
  K[ Beam ] = 0.0; //rho[]*Vector[-9.8,0,0];

  freq = 100;
}

/* -----------------------------------------------------------------------*/

Constraint {
  { Name DeplacementX;
    Case {
      { Region Bottom ; Type Assign ; Value 0; }
    }
  }         
  { Name DeplacementY;
    Case {
      { Region Bottom ; Type Assign ; Value 0; }
    }
  }         
  { Name DeplacementZ;
    Case {
      { Region Bottom ; Type Assign ; Value 0; }
    }
  }         
}

/* -----------------------------------------------------------------------*/

Include "Elasticity_3D.pro"

PostOperation {
  { Name Map_u; NameOfPostProcessing Mec3D_u;
    Operation {
      Print [ u,  OnElementsOf Domain_Disp, File "canti_u.pos" ] ;
    }
  }
}
